# py0 : python zero
Simple python-like scripting language for kids 
## description
This is very simple scripting language which compile to python from file *.py0 to *.py and run them
## you need to install python3 before install py0
pip install py0ltv
## then install Vditor to code
https://github.com/ltvtk/py0/releases/download/1.0/vditor.Setup.1.0.0.exe
